@@ -11,7 +11,7 @@ import typer
 from .. import api
 from . import echo
 
-__version__ = "0.0.9"
+__version__ = "0.0.10"
 
 
 cmd = typer.Typer()
@@ -39,6 +39,7 @@ def add(
     else:
         api.set_app(name)
         echo.progress(f"Updated config to set {name} as the app")
-        api.generate_table_stubs(name)
-        echo.progress(f"Created table definitions in {api.TABLE_STUB_FILE}")
+        generated_stubs = api.generate_table_stubs(name)
+        if generated_stubs:
+            echo.progress(f"Created table definitions in {api.TABLE_STUB_FILE}")
     echo.done()
